This programme is for building C-Vine Copula model based on 
"Statistical arbitrage with vine copulas"
--Johannes Stübinger 2016

build by:
python 3.5
pandas 0.23.0
numpy 1.14.3
rpy2 2.9.4

R and package VineCopula are needed